@@ -1,4 +1,5 @@
 import pytest  # noqa
+from tippo import GenericMeta
 
 import basicco
 
@@ -8,6 +9,8 @@ def test_bases():
     assert basicco.CompatBase
     assert basicco.CompatBase()
 
+    assert issubclass(basicco.CompatBaseMeta, GenericMeta)
+
     assert basicco.BaseMeta
     assert basicco.Base
     assert basicco.Base()
